# **Curvit**
> Create light curves from UVIT data.

<a href="https://ascl.net/2101.013"><img src="https://img.shields.io/badge/ascl-2101.013-blue.svg?colorB=262255" alt="ascl:2101.013" /></a>
<a href="https://pypi.org/project/curvit/"><img src="https://img.shields.io/pypi/v/curvit?color=262255"/></a>
[![Documentation Status](https://readthedocs.org/projects/curvit/badge/?version=latest)](https://curvit.readthedocs.io/en/latest/?badge=latest)

### **Curvit documention is at https://curvit.readthedocs.io**


Curvit is an open-source python package to generate light curves from UVIT (Ultraviolet Imaging Telescope) data.  

The software paper manuscript is accessible at https://arxiv.org/abs/2101.06377

## Installation

Curvit is on the Python Package Index (PyPI) and you can install the package using [pip](https://pip.pypa.io/en/stable/) as follows:

```sh
pip install curvit --user
```

## Report bugs and contribute

If you come across any bugs or mistakes, please report them on the GitHub issue tracker. If you have a solution or a new feature in mind, we welcome you to submit a pull request! Your contributions are greatly appreciated in making Curvit even better.




